==> swf-visualizer-0.3.0.tgz: package/src/components/shared/accordion-item.js <==
import React, { useEffect, useCallback } from 'react'
import { useDispatch, useSelector } from 'react-redux';

import { modalObj } from '../../services/shades-module';
import { updateSavedProject } from '../../store/actions/saved-project-actions';

import { setColorGroup } from '../../store/actions/colors-selection-actions'

import { Accordion } from 'react-bootstrap'
import Checkbox from './checkbox'
import { camelCase } from '../../services/shared'

const AccordionItem = ({
  accordionOption,
  optionType,
}) => {
  const dispatch = useDispatch();
  const dispatchSetColorGroup = useDispatch();
  const savedSceneDetails = useSelector((state) => state.savedScene);

  const defaultProduct = useSelector((state) => state.savedProjects.defaultProduct);
  
  useEffect(() => {
  let options = [];
    if (accordionOption.length > 0) {
        const category = accordionOption.map((item)=>{
            return {name: item.name, val: item.filter_option[0].name, id: item.filter_option[0].id}
        });

        category?.forEach((item) => {
            if(!Object.keys(defaultProduct).includes(camelCase(item.name))){
              item = { [camelCase(item.name)]: item.val };
              options = { ...options, ...item }
            }
        });

        handleCheckBoxChange(options, category);
    }
  }, [accordionOption]);

  const handleCheckBoxChange = useCallback((item, ids) => {
    try {
      const options = { ...defaultProduct, ...item };
      
      if ((options.id === 3 || options.id === 12) && (item['shades/Window'] || item['blinds/Window'])) {
        const type = item['shades/Window'] ? 'shades' : 'blinds';
        const modal = `${options.ar_model_name.split('.')[0]}_${item[`${type}/Window`]}`;
        
        if (savedSceneDetails.currentScene && modalObj[modal]) {
          savedSceneDetails.currentScene.changeBlind(modalObj[modal]);
        }
      }
      
      dispatchSetColorGroup(setColorGroup(ids));
      dispatch(updateSavedProject({ ...options }));
    } catch (error) {
      console.error('Error handling click:', error);
    }
  }, [defaultProduct]);

  const getSelectedOption = (cate, key) => {
    return Object.keys(defaultProduct).includes(camelCase(cate))
      ? defaultProduct[camelCase(cate)]
      : ''
  }

  return (
    <>
      <Accordion className='side-accord color-option-button'>
        {accordionOption?.map((value, key) => (
          <Accordion.Item eventKey={key} id={key} key={key}>
            <Accordion.Header>
              <span className='label-category'> {value.name} </span>
              <span className='label'> {getSelectedOption(value.name, key)} </span>
            </Accordion.Header>
            <Accordion.Body>
              <Checkbox
                optionType='checkbox'
                data={value}
                onCheckBoxChange={(val) => {
                  handleCheckBoxChange({ [camelCase(value.name)]: val.name }, {name: value.name, val: val.name, id: val.id})
                }}
                defaultChecked={defaultProduct[camelCase(value.name)]}
              />
            </Accordion.Body>
          </Accordion.Item>
        ))}
      </Accordion>
    </>
  )
}

export default AccordionItem

==> swf-visualizer-0.4.0.tgz: package/src/components/shared/accordion-item.js <==
import React, { useEffect, useCallback } from 'react'
import { useDispatch, useSelector } from 'react-redux';

import { modalObj } from '@services/shades-module';
import { updateSavedProject } from '@store/actions/saved-project-actions';

import { setColorGroup } from '@store/actions/colors-selection-actions'

import { Accordion } from 'react-bootstrap'
import Checkbox from './checkbox'
import { camelCase } from '@services/shared'

const AccordionItem = ({
  accordionOption,
  optionType,
}) => {
  const dispatch = useDispatch();
  const dispatchSetColorGroup = useDispatch();
  const savedSceneDetails = useSelector((state) => state.savedScene);

  const defaultProduct = useSelector((state) => state.savedProjects.defaultProduct);
  
  useEffect(() => {
  let options = [];
    if (accordionOption.length > 0) {
        const category = accordionOption.map((item)=>{
            return {name: item.name, val: item.filter_option[0].name, id: item.filter_option[0].id}
        });

        category?.forEach((item) => {
            if(!Object.keys(defaultProduct).includes(camelCase(item.name))){
              item = { [camelCase(item.name)]: item.val };
              options = { ...options, ...item }
            }
        });

        handleCheckBoxChange(options, category);
    }
  }, [accordionOption]);

  const handleCheckBoxChange = useCallback((item, ids) => {
    try {
      const options = { ...defaultProduct, ...item };
      
      if ((options.id === 3 || options.id === 12) && (item['shades/Window'] || item['blinds/Window'])) {
        const type = item['shades/Window'] ? 'shades' : 'blinds';
        const modal = `${options.ar_model_name.split('.')[0]}_${item[`${type}/Window`]}`;
        
        if (savedSceneDetails.currentScene && modalObj[modal]) {
          savedSceneDetails.currentScene.changeBlind(modalObj[modal]);
        }
      }
      
      dispatchSetColorGroup(setColorGroup(ids));
      dispatch(updateSavedProject({ ...options }));
    } catch (error) {
      console.error('Error handling click:', error);
    }
  }, [defaultProduct]);

  const getSelectedOption = (cate, key) => {
    return Object.keys(defaultProduct).includes(camelCase(cate))
      ? defaultProduct[camelCase(cate)]
      : ''
  }

  return (
    <>
      <Accordion className='side-accord color-option-button'>
        {accordionOption?.map((value, key) => (
          <Accordion.Item eventKey={key} id={key} key={key}>
            <Accordion.Header>
              <span className='label-category'> {value.name} </span>
              <span className='label'> {getSelectedOption(value.name, key)} </span>
            </Accordion.Header>
            <Accordion.Body>
              <Checkbox
                optionType='checkbox'
                data={value}
                onCheckBoxChange={(val) => {
                  handleCheckBoxChange({ [camelCase(value.name)]: val.name }, {name: value.name, val: val.name, id: val.id})
                }}
                defaultChecked={defaultProduct[camelCase(value.name)]}
              />
            </Accordion.Body>
          </Accordion.Item>
        ))}
      </Accordion>
    </>
  )
}

export default AccordionItem
